import { QueryList, ElementRef, ChangeDetectorRef } from '@angular/core';
import { IgxTreeGridComponent } from './tree-grid.component';
import { IgxRowComponent } from '../row.component';
import { ITreeGridRecord } from './tree-grid.interfaces';
import { GridBaseAPIService } from '../api.service';
import { IgxSelectionAPIService } from '../../core/selection';
export declare class IgxTreeGridRowComponent extends IgxRowComponent<IgxTreeGridComponent> {
    gridAPI: GridBaseAPIService<IgxTreeGridComponent>;
    element: ElementRef;
    cdr: ChangeDetectorRef;
    constructor(gridAPI: GridBaseAPIService<IgxTreeGridComponent>, selection: IgxSelectionAPIService, element: ElementRef, cdr: ChangeDetectorRef);
    private _treeRow;
    /**
     * The rendered cells in the row component.
     *
     * ```typescript
     * const row = this.grid.getRowByKey(1);
     * const cells = row.cells;
     * ```
     */
    cells: QueryList<any>;
    /**
     * The `ITreeGridRecord` passed to the row component.
     *
     * ```typescript
     * const row = this.grid.getRowByKey(1) as IgxTreeGridRowComponent;
     * const treeRow = row.treeRow;
     * ```
     */
    treeRow: ITreeGridRecord;
    /**
     * Returns a value indicating whether the row component is expanded.
     *
     * ```typescript
     * const row = this.grid.getRowByKey(1) as IgxTreeGridRowComponent;
     * const expanded = row.expanded;
     * ```
     */
    /**
    * Sets a value indicating whether the row component is expanded.
    *
    * ```typescript
    * const row = this.grid.getRowByKey(1) as IgxTreeGridRowComponent;
    * row.expanded = true;
    * ```
    */
    expanded: boolean;
    /**
     * @hidden
     */
    protected resolveClasses(): string;
    /** @hidden */
    readonly deleted: boolean;
    /**
     * Checks if any of its parent rows are in deleted state
     * @returns whether any of its parent rows are in deleted state
     */
    private hasDeletedParent;
}
