"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const schematics_1 = require("@angular-devkit/schematics");
const tasks_1 = require("@angular-devkit/schematics/tasks");
// tslint:disable-next-line:no-submodule-imports
const config_1 = require("@schematics/angular/utility/config");
const extSchematicModule = 'igniteui-cli';
const schematicName = 'cli-config';
const hammerJsMinAddress = './node_modules/hammerjs/hammer.min.js';
function logSuccess(options) {
    return (tree, context) => {
        context.logger.info(``);
        context.logger.warn(`Ignite UI for Angular installed`);
        context.logger.info(`Learn more: https://www.infragistics.com/products/ignite-ui-angular`);
        context.logger.info(``);
    };
}
function addDependencies(options) {
    return (tree, context) => {
        const pkgJson = require('../../package.json');
        Object.keys(pkgJson.dependencies).forEach(pkg => {
            const version = pkgJson.dependencies[pkg];
            switch (pkg) {
                case 'hammerjs':
                    addPackageJsonDependency(tree, pkg, version);
                    addHammerJsToWorkspace(tree);
                    LogIncludingDependency(context, pkg, version);
                    break;
                default:
                    addPackageJsonDependency(tree, pkg, version);
                    LogIncludingDependency(context, pkg, version);
                    break;
            }
        });
        addPackageToJsonDevDependency(tree, 'igniteui-cli', pkgJson.devDependencies['igniteui-cli']);
        return tree;
    };
}
function LogIncludingDependency(context, pkg, version) {
    context.logger.log('info', `Including ${pkg} - Version: ${version}`);
}
function addHammerJsToWorkspace(tree) {
    try {
        const targetFile = 'angular.json';
        const workspace = config_1.getWorkspace(tree);
        const addedtoBuildScripts = addHammerToAngularWorkspace(workspace, 'build');
        const addedtoToTestScripts = addHammerToAngularWorkspace(workspace, 'test');
        if (addedtoBuildScripts || addedtoToTestScripts) {
            tree.overwrite(targetFile, JSON.stringify(workspace, null, 2) + '\n');
        }
        return tree;
    }
    catch (e) {
        if (e.toString().includes('Could not find (undefined)')) {
            throw new schematics_1.SchematicsException('angular.json was not found in the project\'s root');
        }
        throw new Error(e.message);
    }
}
/**
 * Add Hammer script to angular.json section
 * @param workspace Angular Workspace Schema (angular.json)
 * @param key Architect tool key to add option to
 */
function addHammerToAngularWorkspace(workspace, key) {
    const currentProjectName = workspace.defaultProject;
    if (currentProjectName) {
        if (!workspace.projects[currentProjectName].architect) {
            workspace.projects[currentProjectName].architect = {};
        }
        if (!workspace.projects[currentProjectName].architect[key]) {
            workspace.projects[currentProjectName].architect[key] = {};
        }
        if (!workspace.projects[currentProjectName].architect[key].options) {
            workspace.projects[currentProjectName].architect[key].options = {};
        }
        if (!workspace.projects[currentProjectName].architect[key].options.scripts) {
            workspace.projects[currentProjectName].architect[key].options.scripts = [];
        }
        if (!workspace.projects[currentProjectName].architect[key].options.scripts.includes(hammerJsMinAddress)) {
            workspace.projects[currentProjectName].architect[key].options.scripts.push(hammerJsMinAddress);
            return true;
        }
        return false;
    }
}
function addPackageJsonDependency(tree, pkg, version) {
    const targetFile = 'package.json';
    if (tree.exists(targetFile)) {
        const sourceText = tree.read(targetFile).toString();
        const json = JSON.parse(sourceText);
        if (!json.dependencies) {
            json.dependencies = {};
        }
        if (!json.dependencies[pkg]) {
            json.dependencies[pkg] = version;
            json.dependencies =
                Object.keys(json.dependencies)
                    .sort()
                    .reduce((result, key) => (result[key] = json.dependencies[key]) && result, {});
            tree.overwrite(targetFile, JSON.stringify(json, null, 2) + '\n');
        }
    }
    return tree;
}
function addPackageToJsonDevDependency(tree, pkg, version) {
    const targetFile = 'package.json';
    if (tree.exists(targetFile)) {
        const sourceText = tree.read(targetFile).toString();
        const json = JSON.parse(sourceText);
        if (!json.devDependencies) {
            json.devDependencies = {};
        }
        if (!json.devDependencies[pkg]) {
            json.devDependencies[pkg] = version;
            json.devDependencies =
                Object.keys(json.devDependencies)
                    .sort()
                    .reduce((result, key) => (result[key] = json.devDependencies[key]) && result, {});
            tree.overwrite(targetFile, JSON.stringify(json, null, 2) + '\n');
        }
    }
    return tree;
}
function installPackageJsonDependencies(options) {
    return (tree, context) => {
        const installTaskId = context.addTask(new tasks_1.NodePackageInstallTask());
        // Add Task for igniteu-cli schematic and wait for install task to finish
        context.addTask(new tasks_1.RunSchematicTask(`${extSchematicModule}`, // Module
        `${schematicName}`, // Schematic Name
        {
            collection: extSchematicModule,
            name: `${schematicName}`,
            options
        }), [installTaskId]);
        return tree;
    };
}
function default_1(options) {
    return schematics_1.chain([
        addDependencies(options),
        installPackageJsonDependencies(options),
        logSuccess(options)
    ]);
}
exports.default = default_1;
