"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const schematics_1 = require("@angular-devkit/schematics");
const testing_1 = require("@angular-devkit/schematics/testing");
const path = require("path");
const config_1 = require("@schematics/angular/utility/config");
describe('schematics', () => {
    const collectionPath = path.join(__dirname, '../collection.json');
    const runner = new testing_1.SchematicTestRunner('cli-schematics', collectionPath);
    let tree;
    const ngJsonConfig = {
        defaultProject: 'testProj',
        projects: {
            testProj: {
                architect: {
                    serve: {}
                }
            }
        }
    };
    const pkgJsonConfig = {
        dependencies: null,
        devDependencies: null
    };
    beforeEach(() => {
        tree = new testing_1.UnitTestTree(new schematics_1.EmptyTree());
        tree.create('/angular.json', JSON.stringify(ngJsonConfig));
        tree.create('/package.json', JSON.stringify(pkgJsonConfig));
    });
    it('should create the needed files correctly', () => {
        expect(tree).toBeTruthy();
        expect(tree.exists('/angular.json')).toBeTruthy();
        expect(tree.exists('/package.json')).toBeTruthy();
        expect(JSON.parse(tree.readContent('/angular.json')).projects['testProj'].architect).toBeTruthy();
        const pkgJsonData = JSON.parse(tree.readContent('/package.json'));
        expect(Object.keys(pkgJsonData).length).toBeGreaterThan(0);
    });
    it('should add packages to package.json dependencies', () => {
        runner.runSchematic('ng-add', {}, tree);
        const pkgJsonData = JSON.parse(tree.readContent('/package.json'));
        expect(pkgJsonData.dependencies).toBeTruthy();
        expect(pkgJsonData.devDependencies).toBeTruthy();
    });
    it('should add the correct igniteui-angular packages to package.json dependencies', () => {
        runner.runSchematic('ng-add', {}, tree);
        const pkgJsonData = JSON.parse(tree.readContent('/package.json'));
        expect(pkgJsonData.dependencies).toBeTruthy();
        const dependenciesFound = Object.keys(pkgJsonData.dependencies)
            .filter(pkg => pkg.includes('igniteui-angular') ||
            pkg.includes('web-animations-js') ||
            pkg.includes('jszip') ||
            pkg.includes('hammerjs'));
        expect(dependenciesFound.length).toBeGreaterThan(0);
    });
    it('should add hammer.js to the workspace', () => {
        runner.runSchematic('ng-add', {}, tree);
        const workspace = config_1.getWorkspace(tree);
        const currentProjectName = workspace.defaultProject;
        expect(workspace.projects[currentProjectName].architect.test.options.scripts.filter(d => d.includes('hammerjs')).length)
            .toBeGreaterThan(0);
        expect(workspace.projects[currentProjectName].architect.build.options.scripts.filter(d => d.includes('hammerjs')).length)
            .toBeGreaterThan(0);
    });
    it('should add hammer.js to package.json dependencies', () => {
        runner.runSchematic('ng-add', {}, tree);
        const pkgJsonData = JSON.parse(tree.readContent('/package.json'));
        expect(pkgJsonData.dependencies).toBeTruthy();
        expect(Object.keys(pkgJsonData.dependencies).filter(k => k.includes('hammerjs')).length).toBeGreaterThan(0);
    });
    it('should add the CLI only to devDependencies', () => {
        runner.runSchematic('ng-add', {}, tree);
        const pkgJsonData = JSON.parse(tree.readContent('/package.json'));
        expect(pkgJsonData.dependencies).toBeTruthy();
        expect(pkgJsonData.devDependencies).toBeTruthy();
        expect(Object.keys(pkgJsonData.devDependencies).filter(k => k.includes('igniteui-cli')).length).toBeGreaterThan(0);
        expect(Object.keys(pkgJsonData.dependencies).filter(k => k.includes('igniteui-cli')).length).toBe(0);
    });
});
